[ARVADOS] updated: 5b2a15b6a4addfc648ef1060be47ffef64e64777

git at public.curoverse.com git at public.curoverse.com
Mon Sep 22 16:50:02 EDT 2014


Summary of changes:
 services/api/db/migrate/20140918153705_add_state_to_job.rb | 4 ++--
 1 file changed, 2 insertions(+), 2 deletions(-)

       via  5b2a15b6a4addfc648ef1060be47ffef64e64777 (commit)
      from  d70e5d076e907266c0f40364aaa69fdce449ce9f (commit)

Those revisions listed above that are new to this repository have
not appeared on any other notification email; so we list those
revisions in full, below.


commit 5b2a15b6a4addfc648ef1060be47ffef64e64777
Author: Tom Clegg <tom at curoverse.com>
Date:   Mon Sep 22 16:49:28 2014 -0400

    3898: Assume a job Failed if it has started but state fields indicate Queued.

diff --git a/services/api/db/migrate/20140918153705_add_state_to_job.rb b/services/api/db/migrate/20140918153705_add_state_to_job.rb
index 176b0e4..20625c9 100644
--- a/services/api/db/migrate/20140918153705_add_state_to_job.rb
+++ b/services/api/db/migrate/20140918153705_add_state_to_job.rb
@@ -9,8 +9,8 @@ class AddStateToJob < ActiveRecord::Migration
       Job.update_all({state: 'Failed'}, ['state is null and success = ?', false])
       Job.update_all({state: 'Complete'}, ['state is null and success = ?', true])
       Job.update_all({state: 'Running'}, ['state is null and running = ?', true])
-      # Locked, but not Running/Failed/Complete? Let's assume it failed.
-      Job.update_all({state: 'Failed'}, ['state is null and is_locked_by_uuid is not null', true])
+      # Locked/started, but not Running/Failed/Complete? Let's assume it failed.
+      Job.update_all({state: 'Failed'}, ['state is null and (is_locked_by_uuid is not null or started_at is not null)'])
       Job.update_all({state: 'Queued'}, ['state is null'])
     end
   end

-----------------------------------------------------------------------


hooks/post-receive
-- 




More information about the arvados-commits mailing list